#!/usr/local/bin/perl -w

=head1 NAME

p4.t - testing of vcp p4 i/o

=cut

use strict ;

use Carp ;
use File::Path ;
use File::Spec ;
use POSIX ':sys_wait_h' ;
use Test ;
use VCP::TestUtils ;

# use eq_or_diff from Test::Differences if available,
# else just use ok.
eval "use Test::Differences";
sub ok_or_diff {
   goto &eq_or_diff if defined &eq_or_diff;
   goto &Test::ok;
}


my @vcp = vcp_cmd ;

my $t = -d 't' ? 't/' : '' ;

my $p4root_0  = "${t}p4root_0";
my $p4state_0 = "${t}p4state_0";
my $p4_rev_root = "//depot/foo/" ;
my $p4_spec = "p4:revml2p4\@$p4root_0:$p4_rev_root" ;
my $p4_repo_id = "p4:test_repository";

my @tests = (

##
## Empty import
##
sub {
   run [ @vcp, "revml:-", $p4_spec,
         "--init-p4d",
         "--delete-p4d-dir", 
         "--db-dir=$p4state_0",
         "--repo-id=$p4_repo_id",
       ],
       \"<revml/>" ; #"#
   ok $?, 0, "`vcp revml:- $p4_spec` return value"  ;
},

##
## revml -> p4 bootstrap export
##
sub {
   my $infile  = $t . "test-p4-in-0.revml" ;
   ok run [ @vcp, "revml:$infile", $p4_spec,
            "--init-p4d",
            "--delete-p4d-dir",
            "--db-dir=$p4state_0",
            "--repo-id=p4:test_repository",
            "--change-branch-rev-1",
         ],
      \undef;
},

## slurp $infile and analyze with regexps to count number of unique
## named files and the highest change number for each file, then check
## state db to see if the repository really contains all that.

## detailed analysis of this import is left to 91p42revml.t             

sub {
   my $infile  = $t . "test-p4-in-0.revml" ;

   # my $p4_options = launch_p4d "p4_", { 
   #    repo_dir    => $p4root_0,
   # } ;

   #my $revs1 = parse_files_and_revids_from_p4_files $p4_rev_root, $p4_options, "//..." ;
   my $revs1 = parse_files_and_revids_from_head_revs_db 
      { state_dir => $p4state_0, repo_id => $p4_repo_id, remove_rev_root => "/ignored/" };
   my $revs2 = parse_files_and_revids_from_revml $infile ;

   ok_or_diff $revs1, $revs2;
},



) ;



plan tests => scalar @tests ;

my $p4d_borken = p4d_borken ;

my $why_skip ;
$why_skip .= "p4 command not found\n"  unless ( `p4 -V`  || 0 ) =~ /^Perforce/ ;
$why_skip .= "$p4d_borken\n"           if $p4d_borken ;

$why_skip ? skip( $why_skip, '' ) : $_->() for @tests ;
